@@ -98,8 +98,7 @@ forest_plot <- function(bg,
   if(show == "covariates")
     fp_labels <- c("Covariate", bg$covariates, NA, "Treatment effect (hypermean)")
   else
-    fp_labels <- c("Group mean treatment effect", group_names(bg), NA, "Hypermean treatment effect")
-
+    fp_labels <- c("Group mean treatment effect", as.character(group_names(bg)), NA, "Hypermean treatment effect")
 
   fp_printed_vals <- c("Mean (SD)", ge_printed, NA, te_printed)
   fp_text <- matrix(c(fp_labels, fp_printed_vals), n_ge_rows + 3, 2, byrow = FALSE)
